# Credits

## Development Leads

- [Greg Tucker](https://github.com/gregtucker)
- [Nicole Gasparini](https://github.com/nicgaspar)
- [Erkan Istanbulluoglu](https://github.com/erkanistan)
- [Daniel Hobley](https://github.com/SiccarPoint)
- [Sai S. Nudurupati](https://github.com/saisiddu)
- [Jordan Adams](https://github.com/jadams15)
- [Eric Hutton](https://github.com/mcflugen)
- [Jenny Knuth](https://github.com/jennyknuth)
- [Katy Barnhart](https://github.com/kbarnhart)
- [Margaux Mouchene](https://github.com/margauxmouchene)
- [Christina Bandaragoda](https://github.com/ChristinaB)
- [Nathan Lyons](https://github.com/nathanlyons)

## Contributors

<!-- credits-roll start-author-list -->

- [Eric Hutton](https://github.com/mcflugen)
- [Katy Barnhart](https://github.com/kbarnhart)
- [Dan Hobley](https://github.com/SiccarPoint)
- [Greg Tucker](https://github.com/gregtucker)
- [Jordan Adams](https://github.com/jadams15)
- [Sai Nudurupati](https://github.com/saisiddu)
- [Nicole M Gasparini](https://github.com/nicgaspar)
- [Charlie Shobe](https://github.com/cmshobe)
- [David Litwin](https://github.com/DavidLitwin)
- [Laurent Roberge](https://github.com/loroberge)
- [Sebastien Lenard](https://github.com/sebastien-lenard)
- [Ronda Strauch](https://github.com/RondaStrauch)
- [Benjamin Campforts](https://github.com/BCampforts)
- [Margaux Mouchene](https://github.com/margauxmouchene)
- [Jenny Knuth](https://github.com/jennyknuth)
- [Berkan M](https://github.com/BerkM125)
- [Jeffrey Keck](https://github.com/keckje)
- [Nathan Lyons](https://github.com/nathanlyons)
- [Allison Pfeiffer](https://github.com/pfeiffea)
- [Rachel Glade](https://github.com/Glader011235)
- [Annie Thompson](https://github.com/anweiii)
- [Giuseppecipolla95](https://github.com/Giuseppecipolla95)
- [Dylan Ward](https://github.com/ddoubleprime)
- [Amanda Alvis](https://github.com/adalvis)
- [Mark Piper](https://github.com/mdpiper)
- [Jay Hariharan](https://github.com/elbeejay)
- [Shelby Ahrendt](https://github.com/shelbyahrendt)
- [Abby Langston](https://github.com/alangston)
- [Andy Wickert](https://github.com/awickert)
- [Christopher Sheehan](https://github.com/Sheehace)
- [Francis Rengers](https://github.com/frengers)
- [Josh Wolpert](https://github.com/josh-wolpert)
- [Kristen Thyng](https://github.com/kthyng)
- [Muneer Ahammad](https://github.com/muneerVT)
- [Sarah Lundell](https://github.com/slundell123)
- [pankajiitkgp](https://github.com/pankajiitkgp)
